@@ -78,7 +78,7 @@ char *FieldLabels[NUM_FIELDS+EXTRA_FIELDS] =
         N_("Full House [25]"),
         N_("Small Straight [30]"),
         N_("Large Straight [40]"),
-        N_("Yahtzee [50]"),
+        N_("5 of a Kind [50]"),
         N_("Chance [total]"),
 	/* End of lower panel */
 	N_("Lower Total"),
@@ -167,21 +167,26 @@ RollSelectedDice(void)
   int i, mod=0;
 
   if (NumberOfRolls >= NUM_ROLLS) {
-          say(_("You're only allowed three rolls! Select a score box."));
-          return;
+    return;
   }
 
   for (i=0; i<5; i++) {
     if (DiceValues[i].sel) {
       DiceValues[i].val = RollDie();
       DiceValues[i].sel = 0;
-      UpdateDie(i);
       mod = 1;
     }
   }
-  
+
+  UpdateAllDicePixmaps();
+  DeselectAllDice();
+
   NumberOfRolls += mod;
 
+  if (NumberOfRolls >= NUM_ROLLS ) {
+    say (_("Choose a score slot."));
+  }
+
 }
 
 int
